@@ -1,11 +1,15 @@
 use crate::Problem;
 use debversion::Version;
 
+/// Problem representing a generic dpkg error.
+///
+/// This struct is used for errors reported by the dpkg package manager
+/// that don't fit into more specific categories.
 #[derive(Debug)]
 pub struct DpkgError(pub String);
 
 impl Problem for DpkgError {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "dpkg-error".into()
     }
 
@@ -26,11 +30,15 @@ impl std::fmt::Display for DpkgError {
     }
 }
 
+/// Problem representing an error during apt-get update.
+///
+/// This struct is used when the apt package database update process
+/// fails for any reason.
 #[derive(Debug, Clone)]
 pub struct AptUpdateError;
 
 impl Problem for AptUpdateError {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "apt-update-error".into()
     }
 
@@ -49,14 +57,20 @@ impl std::fmt::Display for AptUpdateError {
     }
 }
 
+/// Problem representing a failure to fetch a package or repository data.
+///
+/// This struct is used when apt cannot download a package or repository
+/// data from the specified URL.
 #[derive(Debug, Clone)]
 pub struct AptFetchFailure {
+    /// The URL that apt was trying to fetch from, if available.
     pub url: Option<String>,
+    /// The error message from the fetch failure.
     pub error: String,
 }
 
 impl Problem for AptFetchFailure {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "apt-file-fetch-failure".into()
     }
 
@@ -82,11 +96,15 @@ impl std::fmt::Display for AptFetchFailure {
     }
 }
 
+/// Problem representing a missing Release file for a repository.
+///
+/// This struct is used when apt cannot find the Release file for a repository,
+/// which typically indicates a misconfigured or unavailable repository.
 #[derive(Debug, Clone)]
 pub struct AptMissingReleaseFile(pub String);
 
 impl Problem for AptMissingReleaseFile {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "missing-release-file".into()
     }
 
@@ -107,11 +125,15 @@ impl std::fmt::Display for AptMissingReleaseFile {
     }
 }
 
+/// Problem representing a package that apt cannot find.
+///
+/// This struct is used when apt cannot find a requested package in any
+/// of the configured repositories.
 #[derive(Debug, Clone)]
 pub struct AptPackageUnknown(pub String);
 
 impl Problem for AptPackageUnknown {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "apt-package-unknown".into()
     }
 
@@ -132,14 +154,20 @@ impl std::fmt::Display for AptPackageUnknown {
     }
 }
 
+/// Problem representing broken package dependencies.
+///
+/// This struct is used when apt reports broken packages in the dependency
+/// resolution process, which can occur when packages have incompatible dependencies.
 #[derive(Debug, Clone)]
 pub struct AptBrokenPackages {
+    /// A description of the broken package situation.
     pub description: String,
+    /// List of packages that are broken, if available.
     pub broken: Option<Vec<String>>,
 }
 
 impl Problem for AptBrokenPackages {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "apt-broken-packages".into()
     }
 
@@ -161,14 +189,20 @@ impl std::fmt::Display for AptBrokenPackages {
     }
 }
 
+/// Problem representing a missing upstream source tarball.
+///
+/// This struct is used when the build process cannot find the upstream
+/// source tarball for a package, which is required for the build.
 #[derive(Debug, Clone)]
 pub struct UnableToFindUpstreamTarball {
+    /// The name of the package.
     pub package: String,
+    /// The version of the package for which the tarball is missing.
     pub version: Version,
 }
 
 impl Problem for UnableToFindUpstreamTarball {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "unable-to-find-upstream-tarball".into()
     }
 
@@ -194,14 +228,20 @@ impl std::fmt::Display for UnableToFindUpstreamTarball {
     }
 }
 
+/// Problem representing a source format that cannot be built.
+///
+/// This struct is used when the source package format specified in
+/// debian/source/format cannot be built for some reason.
 #[derive(Debug, Clone)]
 pub struct SourceFormatUnbuildable {
+    /// The source format that can't be built (e.g., "3.0 (quilt)").
     pub source_format: String,
+    /// The reason why the source format cannot be built.
     pub reason: String,
 }
 
 impl Problem for SourceFormatUnbuildable {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "source-format-unbuildable".into()
     }
 
@@ -227,11 +267,15 @@ impl std::fmt::Display for SourceFormatUnbuildable {
     }
 }
 
+/// Problem representing a source format that is not supported.
+///
+/// This struct is used when the source package format specified in
+/// debian/source/format is not supported by the build environment.
 #[derive(Debug, Clone)]
 pub struct SourceFormatUnsupported(pub String);
 
 impl Problem for SourceFormatUnsupported {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "source-format-unsupported".into()
     }
 
@@ -252,11 +296,15 @@ impl std::fmt::Display for SourceFormatUnsupported {
     }
 }
 
+/// Problem representing a missing patch file.
+///
+/// This struct is used when a build requires a patch file that is
+/// referenced in the debian/patches directory but is not found.
 #[derive(Debug, Clone)]
 pub struct PatchFileMissing(pub std::path::PathBuf);
 
 impl Problem for PatchFileMissing {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "patch-file-missing".into()
     }
 
@@ -277,14 +325,20 @@ impl std::fmt::Display for PatchFileMissing {
     }
 }
 
+/// Problem representing unexpected local changes in the source package.
+///
+/// This struct is used when dpkg-source detects unexpected local changes
+/// to upstream source code, which should be represented as patches instead.
 #[derive(Debug, Clone)]
 pub struct DpkgSourceLocalChanges {
+    /// Path to the diff file showing the changes, if available.
     pub diff_file: Option<String>,
+    /// List of files that have been changed locally, if available.
     pub files: Option<Vec<String>>,
 }
 
 impl Problem for DpkgSourceLocalChanges {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "unexpected-local-upstream-changes".into()
     }
 
@@ -316,11 +370,15 @@ impl std::fmt::Display for DpkgSourceLocalChanges {
     }
 }
 
+/// Problem representing changes that cannot be represented in the source package.
+///
+/// This struct is used when dpkg-source detects changes that cannot be
+/// represented in the chosen source format, such as mode changes in some formats.
 #[derive(Debug, Clone)]
 pub struct DpkgSourceUnrepresentableChanges;
 
 impl Problem for DpkgSourceUnrepresentableChanges {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "unrepresentable-local-changes".into()
     }
 
@@ -339,11 +397,15 @@ impl std::fmt::Display for DpkgSourceUnrepresentableChanges {
     }
 }
 
+/// Problem representing unwanted binary files in the source package.
+///
+/// This struct is used when dpkg-source detects binary files in the source
+/// package that are not allowed, which can happen when the source is dirty.
 #[derive(Debug, Clone)]
 pub struct DpkgUnwantedBinaryFiles;
 
 impl Problem for DpkgUnwantedBinaryFiles {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "unwanted-binary-files".into()
     }
 
@@ -362,11 +424,15 @@ impl std::fmt::Display for DpkgUnwantedBinaryFiles {
     }
 }
 
+/// Problem representing changes to binary files in the source package.
+///
+/// This struct is used when dpkg-source detects that binary files have been
+/// changed, which cannot be properly represented in source package formats.
 #[derive(Debug, Clone)]
 pub struct DpkgBinaryFileChanged(pub Vec<String>);
 
 impl Problem for DpkgBinaryFileChanged {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "binary-file-changed".into()
     }
 
@@ -387,11 +453,15 @@ impl std::fmt::Display for DpkgBinaryFileChanged {
     }
 }
 
+/// Problem representing a missing debian control file.
+///
+/// This struct is used when the debian/control file, which is required for
+/// any Debian package, is missing from the source package.
 #[derive(Debug, Clone)]
 pub struct MissingControlFile(pub std::path::PathBuf);
 
 impl Problem for MissingControlFile {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "missing-control-file".into()
     }
 
@@ -410,11 +480,15 @@ impl std::fmt::Display for MissingControlFile {
     }
 }
 
+/// Problem representing unknown Mercurial extra fields.
+///
+/// This struct is used when the build process encounters unknown extra fields
+/// in Mercurial version control metadata.
 #[derive(Debug, Clone)]
 pub struct UnknownMercurialExtraFields(pub String);
 
 impl Problem for UnknownMercurialExtraFields {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "unknown-mercurial-extra-fields".into()
     }
 
@@ -435,11 +509,15 @@ impl std::fmt::Display for UnknownMercurialExtraFields {
     }
 }
 
+/// Problem representing a failure to verify an upstream PGP signature.
+///
+/// This struct is used when the build process cannot verify the PGP signature
+/// of an upstream source tarball, which may indicate a security issue.
 #[derive(Debug, Clone)]
 pub struct UpstreamPGPSignatureVerificationFailed;
 
 impl Problem for UpstreamPGPSignatureVerificationFailed {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "upstream-pgp-signature-verification-failed".into()
     }
 
@@ -458,11 +536,15 @@ impl std::fmt::Display for UpstreamPGPSignatureVerificationFailed {
     }
 }
 
+/// Problem representing a missing requested version in uscan.
+///
+/// This struct is used when the uscan tool (which checks for upstream versions)
+/// cannot find a specifically requested version.
 #[derive(Debug, Clone)]
 pub struct UScanRequestVersionMissing(pub String);
 
 impl Problem for UScanRequestVersionMissing {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "uscan-request-version-missing".into()
     }
 
@@ -483,11 +565,15 @@ impl std::fmt::Display for UScanRequestVersionMissing {
     }
 }
 
+/// Problem representing a failure in the debcargo tool.
+///
+/// This struct is used when the debcargo tool, which is used to package
+/// Rust crates as Debian packages, encounters an error.
 #[derive(Debug, Clone)]
 pub struct DebcargoFailure(pub String);
 
 impl Problem for DebcargoFailure {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "debcargo-failure".into()
     }
 
@@ -508,11 +594,15 @@ impl std::fmt::Display for DebcargoFailure {
     }
 }
 
+/// Problem representing an error parsing a debian/changelog file.
+///
+/// This struct is used when the build process encounters a syntax error
+/// or other issue when parsing the debian/changelog file.
 #[derive(Debug, Clone)]
 pub struct ChangelogParseError(pub String);
 
 impl Problem for ChangelogParseError {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "changelog-parse-error".into()
     }
 
@@ -533,11 +623,15 @@ impl std::fmt::Display for ChangelogParseError {
     }
 }
 
+/// Problem representing a generic error in the uscan tool.
+///
+/// This struct is used when the uscan tool, which checks for upstream versions,
+/// encounters an error that doesn't fit into more specific categories.
 #[derive(Debug, Clone)]
 pub struct UScanError(pub String);
 
 impl Problem for UScanError {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "uscan-error".into()
     }
 
@@ -558,14 +652,20 @@ impl std::fmt::Display for UScanError {
     }
 }
 
+/// Problem representing a failure in the uscan tool.
+///
+/// This struct is used when the uscan tool fails to find or process
+/// upstream versions from a specific URL.
 #[derive(Debug, Clone)]
 pub struct UScanFailed {
+    /// The URL that uscan was trying to process.
     pub url: String,
+    /// The reason for the failure.
     pub reason: String,
 }
 
 impl Problem for UScanFailed {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "uscan-failed".into()
     }
 
@@ -587,14 +687,20 @@ impl std::fmt::Display for UScanFailed {
     }
 }
 
+/// Problem representing inconsistency between source format and version.
+///
+/// This struct is used when there's an inconsistency between the source format
+/// specified in debian/source/format and the version numbering scheme.
 #[derive(Debug, Clone)]
 pub struct InconsistentSourceFormat {
+    /// Whether the version is inconsistent with the source format.
     pub version: bool,
+    /// Whether the source format is inconsistent with the version.
     pub source_format: bool,
 }
 
 impl Problem for InconsistentSourceFormat {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "inconsistent-source-format".into()
     }
 
@@ -619,14 +725,20 @@ impl std::fmt::Display for InconsistentSourceFormat {
     }
 }
 
+/// Problem representing an error parsing the debian/upstream/metadata file.
+///
+/// This struct is used when the build process cannot parse the
+/// debian/upstream/metadata file, which contains information about the upstream project.
 #[derive(Debug, Clone)]
 pub struct UpstreamMetadataFileParseError {
+    /// The path to the metadata file.
     pub path: std::path::PathBuf,
+    /// The reason for the parsing failure.
     pub reason: String,
 }
 
 impl Problem for UpstreamMetadataFileParseError {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "debian-upstream-metadata-invalid".into()
     }
 
@@ -648,11 +760,15 @@ impl std::fmt::Display for UpstreamMetadataFileParseError {
     }
 }
 
+/// Problem representing a failure in dpkg-source when packaging source files.
+///
+/// This struct is used when dpkg-source cannot package the source files
+/// into a source package for various reasons.
 #[derive(Debug, Clone)]
 pub struct DpkgSourcePackFailed(pub String);
 
 impl Problem for DpkgSourcePackFailed {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "dpkg-source-pack-failed".into()
     }
 
@@ -673,14 +789,20 @@ impl std::fmt::Display for DpkgSourcePackFailed {
     }
 }
 
+/// Problem representing an invalid version string in a package.
+///
+/// This struct is used when dpkg encounters a version string that
+/// doesn't follow the Debian version format rules.
 #[derive(Debug, Clone)]
 pub struct DpkgBadVersion {
+    /// The invalid version string.
     pub version: String,
+    /// The reason why the version is invalid, if available.
     pub reason: Option<String>,
 }
 
 impl Problem for DpkgBadVersion {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "dpkg-bad-version".into()
     }
 
@@ -706,14 +828,20 @@ impl std::fmt::Display for DpkgBadVersion {
     }
 }
 
+/// Problem representing a missing Rust crate in debcargo.
+///
+/// This struct is used when debcargo cannot find a Rust crate
+/// that is required for the build.
 #[derive(Debug, Clone)]
 pub struct MissingDebcargoCrate {
+    /// The name of the missing Rust crate.
     pub cratename: String,
+    /// The version of the crate that is required, if specified.
     pub version: Option<String>,
 }
 
 impl Problem for MissingDebcargoCrate {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "debcargo-missing-crate".into()
     }
 
@@ -744,6 +872,16 @@ impl std::fmt::Display for MissingDebcargoCrate {
 }
 
 impl MissingDebcargoCrate {
+    /// Creates a MissingDebcargoCrate instance from a string.
+    ///
+    /// Parses a string in the format "cratename=version" or just "cratename"
+    /// to create a new instance.
+    ///
+    /// # Arguments
+    /// * `text` - The string to parse
+    ///
+    /// # Returns
+    /// A new MissingDebcargoCrate instance
     pub fn from_string(text: &str) -> Self {
         let text = text.trim();
         if let Some((cratename, version)) = text.split_once('=') {
@@ -760,11 +898,15 @@ impl MissingDebcargoCrate {
     }
 }
 
+/// Problem representing a missing pristine-tar tree reference.
+///
+/// This struct is used when a pristine-tar operation cannot find
+/// a referenced tree in the git repository.
 #[derive(Debug, Clone)]
 pub struct PristineTarTreeMissing(pub String);
 
 impl Problem for PristineTarTreeMissing {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "pristine-tar-missing-tree".into()
     }
 
@@ -785,11 +927,15 @@ impl std::fmt::Display for PristineTarTreeMissing {
     }
 }
 
+/// Problem representing a missing revision in version control.
+///
+/// This struct is used when a build process references a revision
+/// in version control that does not exist.
 #[derive(Debug, Clone)]
 pub struct MissingRevision(pub Vec<u8>);
 
 impl Problem for MissingRevision {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "missing-revision".into()
     }
 
@@ -810,14 +956,20 @@ impl std::fmt::Display for MissingRevision {
     }
 }
 
+/// Problem representing a Rust crate dependency predicate that debcargo cannot handle.
+///
+/// This struct is used when debcargo cannot represent a predicate in a Rust
+/// crate dependency, such as certain prerelease version constraints.
 #[derive(Debug)]
 pub struct DebcargoUnacceptablePredicate {
+    /// The name of the crate with the unacceptable predicate.
     pub cratename: String,
+    /// The predicate that cannot be represented.
     pub predicate: String,
 }
 
 impl Problem for DebcargoUnacceptablePredicate {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "debcargo-unacceptable-predicate".into()
     }
 
@@ -843,14 +995,20 @@ impl std::fmt::Display for DebcargoUnacceptablePredicate {
     }
 }
 
+/// Problem representing a Rust crate dependency comparator that debcargo cannot handle.
+///
+/// This struct is used when debcargo cannot represent a version comparison operator
+/// in a Rust crate dependency, such as certain complex version constraints.
 #[derive(Debug)]
 pub struct DebcargoUnacceptableComparator {
+    /// The name of the crate with the unacceptable comparator.
     pub cratename: String,
+    /// The comparator that cannot be represented.
     pub comparator: String,
 }
 
 impl Problem for DebcargoUnacceptableComparator {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "debcargo-unacceptable-comparator".into()
     }
 
@@ -876,11 +1034,15 @@ impl std::fmt::Display for DebcargoUnacceptableComparator {
     }
 }
 
+/// Problem representing a "too many requests" error from uscan.
+///
+/// This struct is used when uscan receives a rate limiting response
+/// from a server it is checking for upstream versions.
 #[derive(Debug)]
 pub struct UScanTooManyRequests(pub String);
 
 impl Problem for UScanTooManyRequests {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "uscan-too-many-requests".into()
     }
 
@@ -901,11 +1063,15 @@ impl std::fmt::Display for UScanTooManyRequests {
     }
 }
 
+/// Problem representing unsatisfied conflicts in apt dependencies.
+///
+/// This struct is used when apt cannot resolve package conflicts
+/// during the dependency resolution process.
 #[derive(Debug)]
 pub struct UnsatisfiedAptConflicts(pub String);
 
 impl Problem for UnsatisfiedAptConflicts {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "unsatisfied-apt-conflicts".into()
     }
 
@@ -928,14 +1094,20 @@ impl std::fmt::Display for UnsatisfiedAptConflicts {
 
 impl std::error::Error for UnsatisfiedAptConflicts {}
 
+/// Problem representing an architecture not in the supported architecture list.
+///
+/// This struct is used when a build is attempted for an architecture that
+/// is not in the list of architectures supported by the package.
 #[derive(Debug, Clone)]
 pub struct ArchitectureNotInList {
+    /// The architecture being built for.
     pub arch: String,
+    /// The list of supported architectures.
     pub arch_list: Vec<String>,
 }
 
 impl Problem for ArchitectureNotInList {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "arch-not-in-list".into()
     }
 
@@ -957,11 +1129,15 @@ impl std::fmt::Display for ArchitectureNotInList {
     }
 }
 
+/// Problem representing unsatisfied dependencies in apt.
+///
+/// This struct is used when apt cannot satisfy the dependencies
+/// required for a package installation.
 #[derive(Debug)]
 pub struct UnsatisfiedAptDependencies(pub String);
 
 impl Problem for UnsatisfiedAptDependencies {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "unsatisfied-apt-dependencies".into()
     }
 
@@ -982,14 +1158,20 @@ impl std::fmt::Display for UnsatisfiedAptDependencies {
     }
 }
 
+/// Problem representing insufficient disk space for a build.
+///
+/// This struct is used when a build process determines that there is
+/// not enough disk space available to complete the build.
 #[derive(Debug)]
 pub struct InsufficientDiskSpace {
+    /// The amount of disk space needed for the build in KiB.
     pub needed: i64,
+    /// The amount of free disk space available in KiB.
     pub free: i64,
 }
 
 impl Problem for InsufficientDiskSpace {
-    fn kind(&self) -> std::borrow::Cow<str> {
+    fn kind(&self) -> std::borrow::Cow<'_, str> {
         "insufficient-disk-space".into()
     }
 
@@ -1014,3 +1196,27 @@ impl std::fmt::Display for InsufficientDiskSpace {
         )
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+    use crate::Problem;
+
+    #[test]
+    fn test_dpkg_source_local_changes_trait() {
+        let problem = DpkgSourceLocalChanges {
+            diff_file: Some("/tmp/diff.patch".to_string()),
+            files: Some(vec!["file1.txt".to_string(), "file2.txt".to_string()]),
+        };
+        let json = problem.json();
+        assert_eq!(json["diff_file"], "/tmp/diff.patch");
+        assert_eq!(json["files"], serde_json::json!(["file1.txt", "file2.txt"]));
+    }
+
+    #[test]
+    fn test_uscan_too_many_requests_trait() {
+        let problem = UScanTooManyRequests("rate limit exceeded".to_string());
+        let json = problem.json();
+        assert_eq!(json["reason"], "rate limit exceeded");
+    }
+}
